% ODE for smoking model
% x is prevalence of smoking
%
% Input:
%   - t: time
%   - x: [dependent var., a, b, ux0, ux1, tstar/delta]

function dx = multi_smk(t,x)
global model_no knowl

% make sure 0<= x0 <=1
x0 = min(max(0, x(1)), 1);

% define parameters
a = x(2); b = x(3); ux0 = x(4); ux1 = x(5); tstar = x(6);

if model_no == 1
    if t <= tstar
        ux = ux0;
    else
        ux = ux1;
    end
elseif model_no == 2
    idx = find(knowl(:,1)>=t, 1);
    
    % Interpolate number of articles at time t
    if ~isempty(idx)
        n = knowl(idx,2)*(t-knowl(idx-1,1)) + knowl(idx-1,2)*(knowl(idx,1)-t);
        n = n/(knowl(idx,1)-knowl(idx-1,1));
    else
        n = knowl(end,2);
    end
    
    % Calculate Ux
    ux = ux1 + tstar^(n-1)*(ux0-ux1);
end

dx = [b*( (1-x0)*x0^a*ux - x0*(1-x0)^a*(1-ux) );...
    0; 0; 0; 0; 0];